// **** BEGIN LICENSE BLOCK ****
//   Copyright(c) 2009-2010 MATSUZAWA Jiro
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
//   02110-1301, USA.  */
// **** END LICENSE BLOCK ****

var rencon;
if (!rencon) {
    rencon = {};
} else if (typeof rencon != "object") {
    throw new Error("cannot use rencon");
}

rencon.PubMedParser = function(){}
rencon.PageParser.cloneParser(rencon.PubMedParser);

rencon.PubMedParser.prototype = {
    pickoutBibRecord : function()
    {
        var recordList;
        var record;
        var title, creator, journal, volume, pubDate, pages, url;
        var journalInfo;
        recordList = this._getRecordList();
        for (var i = 0; i < recordList.length; ++i) {
            title = this._getTitle(recordList[i]);
            creator = this._getCreator(recordList[i]);
            journal = this._getJournal(recordList[i]);

            journalInfo = recordList[i].getElementsByClassName("src")[0].lastChild.data;
            journalInfo = this._cutJournalInfoExtra(journalInfo);

            pubDate = this._getPubDate(journalInfo);
            volume = this._getVolume(journalInfo);
            pages = this._getPages(journalInfo);
            url = this._getUrl(recordList[i]);

            record = new rencon.ArticleRecord(title, creator, pubDate, url, journal, volume, pages);
            rencon.bibTable.addRecord(record);
        }
    },


    _getRecordList : function()
    {
        var recordList = null;
        recordList = window._content.document.getElementsByClassName("rslt");
        if (!recordList) {
            throw new Error("no records information");
        }

        return recordList;
    },


    _getTitle : function(item)
    {
        return item.getElementsByTagName("a")[0].text;
    },


    _getCreator : function(item)
    {
        var creator;
        creator =  item.getElementsByClassName("rprtbody")[0].textContent;
        if (creator.charAt(creator.length-1) == ".") {
            return creator.slice(0, creator.length-1);
        }
        return creator;
    },


    _getJournal : function(item)
    {
        return item.getElementsByClassName("jrnl")[0].title;
    },


    _getPubDate : function(jnlInfo)
    {
        var semiColonIdx = jnlInfo.indexOf(";");
        if (semiColonIdx != -1) {
            return jnlInfo.slice(0, semiColonIdx);
        }

        var colonIdx = jnlInfo.indexOf(":");
        if (colonIdx != -1) {
            return jnlInfo.slice(0, colonIdx);
        }
        return jnlInfo;
    },


    _getVolume : function(jnlInfo)
    {
        var semiColonIdx = jnlInfo.indexOf(";");
        if (semiColonIdx == -1) {
            return "";
        }

        var colonIdx = jnlInfo.indexOf(":");
        if (colonIdx != -1) {
            return jnlInfo.slice(semiColonIdx+1, colonIdx);
        }
        return jnlInfo.slice(semiColonIdx+1);
    },


    _getPages : function(jnlInfo)
    {
        var pages;
        var colonIdx;
        var semiColonIdx;
        if ((colonIdx = jnlInfo.indexOf(":")) != -1) {
            pages = jnlInfo.slice(colonIdx+1);
        } else if ((semiColonIdx = jnlInfo.indexOf(";")) != -1) {
            pages = jnlInfo.slice(semiColonIdx+1);
        } else {
            return "";
        }
        return this._calcPages(pages);
    },


    _getUrl : function(item)
    {
        var url = item.getElementsByClassName("status_free")[0];
        if (!url) {
            return "";
        }
        return url.href;
    },


    _cutJournalInfoExtra : function(info)
    {
        if (info.slice(0, 2) == ". ") {
            info = info.slice(2);
        }

        var dotIdx = info.indexOf(".");
        if (dotIdx == -1) {
            return info;
        }
        return info.slice(0, dotIdx);
    },


    _calcPages : function(pages)
    {
        var from, to;
        var diffByLength;
        var sepIdx = pages.indexOf("-");
        if (sepIdx == -1) {
            return pages
        }
        from = pages.slice(0, sepIdx);
        to = pages.slice(sepIdx+1);
        diffByLength = from.length - to.length;
        if (diffByLength > 0) {
            to = from.slice(0, diffByLength) + to;
        }
        return from + "-" + to;
    },
};
